@ECHO OFF
rem -------------------------------------------------------------------------
rem - Wpro.BAT
rem -
rem - Process CTD data with SBE Windows processing.
rem -
rem - This file is a shell which runs SBEbatch. Define the input text/batch file as 
rem - well as directories for input, output and .psa files. 
rem -
rem - Assumptions:
rem -	1) The .CON file is in the raw data directory with the .DAT file
rem -	2) The processed data directory is different than the raw data directory
rem -	3) The .psa file will have the same name as the processing file it sets up
rem -		Example: AlignCtd will use AlignCtd.psa as a set up file
rem -		Exception: There are two .psa files for DERIVE
rem -			   they are derive.psa and deriveO2.psa 
rem -
rem - Command line argument (%1) is the raw data file name without extention
rem -	Example: If raw CTD data file is CTD001.DAT you would enter "CTD001" 	
rem -
rem -
rem -   Vers    Date            Remarks        
rem -   ====    =========       =======
rem -	1.00	27-Jan-03	W. L. Fanning - Begin.
rem -	1.01	29-Jan-03	WLF - Tidy up, add comments.
rem -	1.02	01-Feb-03	WLF - Add error handling
rem -	1.03	11-Mar-03	LAB - For EN378
rem -	1.04	24-Mar-03	LAB - For EN379
rem -	1.05	29-Apr-03	LAB - For EN380
rem -	1.06	12-Jun-03	LAB - For EN382
rem -	1.07	02-Jul-03	LAB - For EN383
rem -	1.08	12-Aug-03	LAB - For EN385
rem -	1.09	16-Nov-03	LAB - For EN386
rem -	1.10	26-Nov-03	LAB - For EN387
rem -	1.11	08-Jan-04	LAB - For EN388
rem -	1.12	08-Jan-04	LAB - For EN389
rem -	1.13	08-Jan-04	LAB - For EN390
rem -	1.14	07-Mar-04	LAB - For EN391
rem -	1.15	13-Apr-04	LAB - For EN392
rem -	1.16	13-May-04	LAB - For EN393
rem -	1.17	03-Jun-04	LAB - For EN394
rem -	1.18	12-Sep-04	LAB - For EN399
rem -	1.19	09-Nov-04	LAB - For EN400 (change 4 #s to new cruise, Change psu to psa)
rem -	1.20	06-Jan-05	LAB - For EN401 (change 4 #s to new cruise & change 401Datcnv.psa to 401Datcnv_a.psa)
rem -	1.21	03-Mar-05	LAB - For EN402 (change 4 #s to new cruise & change 402Datcnv.psa to 402Datcnv_a.psa)
rem -	1.22	29-Mar-05	LAB - For EN403 (change 4 #s to new cruise & change 402module8.psa to 403Datcnv_1.psa)
rem -	1.23	14-Apr-05	LAB - For EN404 (change 4 #s to new cruise & change 403Datcnv_1.psa to 404Datcnv_a.psa)
rem -	1.24	14-Apr-05	LAB - For EN405 (change 4 #s to new cruise & change 404Datcnv_a.psa to 405Datcnv_1.psa)
rem -	1.25	14-Apr-05	LAB - For EN406 (change 4 #s to new cruise & change 405Datcnv_1.psa to 406Datcnv_1.psa)
rem -	1.26	14-Apr-05	LAB - For EN407 (change 4 #s to new cruise & change 406Datcnv_1.psa to 407Datcnv_1.psa)
rem -	1.27	14-Apr-05	LAB - For EN408 (change 4 #s to new cruise & change 407Datcnv_1.psa to 408Datcnv_1.psa)
rem -	1.28	06-Sep-05	LAB - For EN410 (change 4 #s to new cruise & change 408Datcnv_1.psa to 410Datcnv_1.psa)
rem -	1.29	13-Dec-05	LAB - For EN414 (change 4 #s to new cruise & change 410Datcnv_1.psa to 414Datcnv_1.psa)
rem -	1.30	16-Apr-06	LAB - For EN416 (change 4 #s to new cruise & change 414Datcnv_1.psa to 416Datcnv_a.psa)
rem -	1.31	16-Apr-06	LAB - For EN416 (change 4 #s to new cruise & change 414Datcnv_a.psa to 416Datcnv_b.psa)
rem -	1.32	16-Apr-06	LAB - For EN416 (change 4 #s to new cruise & change 416Datcnv_b.psa to 416Datcnv_c.psa)
rem -	1.33	16-Apr-06	LAB - For EN416 (change 4 #s to new cruise & change 416Datcnv_c.psa to 416Datcnv_hpss.psa)
rem -	1.34	16-Apr-06	LAB - For EN424 (change 4 #s to new cruise & change 416Datcnv_hpss.psa to 424Datcnv_a.psa)
rem -	1.425	05-Sep-06	LAB - For EN425 (change 4 #s to new cruise & change 424Datcnv_a.psa to 425Datcnv_a.psa)
rem -
rem
rem -------------------------------------------------------------------------
rem -------------------------------------------------------------------------


rem -------------------------------------------------------------------------
rem - Define batch/text file and directories with the "SET" statement
rem 	Note: Do not include final backslash for directories
rem
rem	BatchDir - Location of SBEbatch.exe
rem	TxtFile - Path and name of SBE "batch file" containing processing instructions 	
rem 	RawDir  - Raw data directory (input)
rem 	ProDir - Processed directory (output)
rem 	psaDir  - Program Set Up directory (.psa)
rem
rem -------------------------------------------------------------------------
set BatchDir=C:\sspro\SBEDataProcessing-Win32
set TxtFile=C:\sspro\WPro425_a.txt
set RawDir=C:\sswin\data
set ProDir=C:\sswin\data\list
rem set PsuDir=C:\sspro
set PsaDir=C:\sspro


rem - Normally all configuration is done above this line
rem 
rem -------------------------------------------------------------------------
rem - Be sure castname was entered, be sure files and directories exist
rem -------------------------------------------------------------------------
if "%1"=="" goto NOARG
if not exist %TxtFile% goto BADENV
if not exist %RawDir%\%1.DAT goto BADENV
if not exist %BatchDir%\SBEbatch.exe goto BADENV
if not exist %PsaDir%\425Datcnv_a.psa goto BADENV


rem -------------------------------------------------------------------------
rem - Say what's happening.
rem -------------------------------------------------------------------------
echo.
echo CTD Processing of %1
echo Batch Dir : %BatchDir%
echo Batch File: %TxtFile%
echo Input from: %RawDir%
echo Output to : %ProDir%
echo psa files : %psaDir%


rem -------------------------------------------------------------------------
rem - Process Data. 
rem -------------------------------------------------------------------------
copy %RawDir%\%1.CON %ProDir%
%BatchDir%\sbebatch.exe %TxtFile% %RawDir% %1 %ProDir% %psaDir%


rem ------------------------------------------------------------------------
rem - Done: say bye, go home
rem ------------------------------------------------------------------------
echo. 
echo Batch processing of %1 launched...
goto END                                  


rem -------------------------------------------------------------------------
rem - Error handlers here.
rem -------------------------------------------------------------------------

:NOARG
echo.
echo.
echo Usage: %0 castname
echo.
echo castname is the name of the raw data file without path
echo or .DAT extention
echo.
echo	Example: If the raw CTD data is "C:\CtdData\CTD001.DAT" you
echo		 would enter "CTD001"
echo.
goto END


:BADENV
echo.
echo Invalid setup parameter(s) in %0 as follows:
if not exist %TxtFile%    echo Batch File does not exist: %TxtFile%
if not exist %RawDir%\%1.DAT    echo Raw CTD data file does not exist: %RawDir%\%1.DAT
if not exist %BatchDir%\SBEbatch.exe echo Batch processing file not found: %BatchDir%\SBEbatch.exe
if not exist %PsaDir%\425Datcnv_a.psa echo Batch PSA file not found: %PsaDir%\425Datcnv_a.psa
echo.
goto END


:END

rem -------------------------------------------------------------------------
rem - Clean up
rem -------------------------------------------------------------------------

:END
set BatchDir=
set TxtFile=                         
set RawDir=
set ProDir=
set psaDir=
